function d = density(H,w,iter)

% Density weighting for regridding using
% preconditioned conjugate gradient.
%
% Inputs
%  H is the interpolation matrix from setup.m
%  w is the regularization term (eg. max(max(H)))
%  iter is the number of iterations (eg. 10)
%
%(c) Mark Bydder

[m n] = size(H);

% calculate density
d     = H*(ones(1,m)*H)';
d(d>0)= 1./d(d>0);
g     = d./(1 + w^2*d);
r     = H*(ones(1,n) - d'*H)';
s     = r.*g;
new   = r'*s;
for k = 1:iter
    q     =  H*(s'*H)' + w^2*s;
    alpha =  new/(s'*q);
    d     =  d + alpha*s;
    r     =  r - alpha*q;
    q     =  r.*g;
    old   =  new;
    new   =  r'*q;
    if new<=0; break; end
    s     =  q + (new/old)*s;
end

% check for negatives
if any(d<0)
    disp(['*** density negative ***'])
end
