 function [R, kappa] = geniterrecpen(G, tfwhm, is_gram, med_r2s)
%function [R, kappa] = geniterrecpen(G, tfwhm, [is_gram,] [med_r2s])
% Generates the penalty for system matrix G
%
% in
%       G                       recon. system matrix (Gmri/block_fatrix(col))
%       tfwhm                   target fwhm
%       is_gram (bool)          calculate using gram object (default: false)
%       med_r2s                 median r2* value (default is median(real(zmap(mask))))
% out
%       R                       penalty object
%       kappa                   kappa map

% defaults
if ~exist('is_gram', 'var')
    is_gram = false;
end

% Extract parameters from G
if strcmp(G.caller, 'Gmri')
    Gcell = {G};
elseif strcmp(G.caller, 'block_fatrix(col)')
    Gcell = G.arg.blocks;
else
    error 'G has to be ''Gmri'' or ''block_fatrix(col)'''
end
mask = Gcell{1}.arg.mask;
zmap = Gcell{1}.arg.zmap;


% function variables
Rb1 = Robject(mask, 'edge_type', 'leak', 'order', 1, 'beta', 1); % penalty with beta 1


% make system matrix (GR) and kappa map to find beta and R
if ~any(real(zmap(:)))
    if ~isempty(zmap)
        error 'G cannot have only field map'
    end

    GR = G;
    kappa = mask;
else
    if ~exist('med_r2s', 'var')
        med_r2s = median(real(zmap));
    end
    med_r2s_map = med_r2s.*double(mask);
    
    for prnum = 1:length(Gcell)
        % make time vector (shot dependent)
        tt = Gcell{prnum}.arg.ti;

        Gcell{prnum} = feval(Gcell{prnum}.arg.new_zmap, Gcell{prnum}, ...
                tt, med_r2s_map, 1, 1);  % L = aL = 1 is plenty
    end % for prnum
    
    if length(Gcell) == 1
        GR = Gcell{1};
    else
        GR = block_fatrix(Gcell, 'type', 'col');
    end
    kappa = r2s_kappa(G, med_r2s);
end

beta = res2beta(GR, Rb1.C, @qpwls_psf, tfwhm, [0 0], mask, is_gram);
R = Robject(kappa, 'edge_type', 'leak', 'order', 1, 'beta', beta);
