%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function raw=getrawdata(Pfilename, slice, reps, is20x)
% raw data (raw)

% default inputs
if ~exist('is20x','var') || isempty(is20x)
   is20x = false;
end

if is20x
    grrecon = 'grFmap20x';
else
    grrecon = 'grFmap';
end

% get gr from same directory as matlab_gr6
fullloc = which(caller_name);
loc=fullloc(1:(end-(length(caller_name)+2)));
command = [loc grrecon ' -saveraw -noimgfiles 1'];

if ~exist('reps')
    reps = -1;
end;

if slice~=0     % recon one slice at a time
 
    addstr =  [' -sl1 ',num2str(slice), ' -sl2 ',num2str(slice), ' '];
else
    addstr = [];
end;
command = [command addstr];

if reps > 0
    addstr = [' -reps ',num2str(reps)];
else
    addstr = [];
end
command = [command addstr];

%addstr = [' ',Pfilename,' ',Pfilename,'_temp > groutput'];
addstr = [' ',Pfilename,' pfile_temp > groutput'];
command = [command addstr];

system(command);
h = parse_grhead('groutput');
if ( ~isfield(h,'sense'))
    h.sense=1;
end

if slice ~=0
    h.nslices=1;
end

if reps > 0;
    h.reps = reps;
end

%figure; plot(kx,ky); title('kx, ky trajectory read in from P-file');

if(h.spio > 0)
    h.nsamp = h.nsamp/2;        % nsamp from gr is rhfrsize
    % spiogap neq 0 not yet supported!!!
end
% 
%     raw = float('single');
%     reorderrawdata = float('single');
    
% for reordered data:
load reorderrawdata.txt
if h.recotype == 2
    h.necho = 1; % hardwire this value to 1 for 3D recon.
    h.sptraj = 1;
    if (h.spio==1) | (h.spio ==2)
        raw=zeros(h.nsamp*h.nl*2*h.ncoil*h.reps*h.necho*h.nslices,1);
    elseif (h.spio==3) | (h.spio ==4)
        raw=zeros(h.nsamp*h.nl*h.ncoil*h.reps*h.necho*h.nslices,1);
    elseif h.spio == 0
        raw=zeros(h.nsamp*h.nl*h.ncoil*h.reps*h.necho*h.nslices,1);
    else
        error('spio mode not supported');
    end
else
  %  raw = float('single');
    raw=zeros(h.nsamp*h.nl*h.ncoil*h.reps*h.necho*h.nslices,1);
end

if slice~=0     % have to fill matrix piecewise as crashes matlab
    for kk=1:size(raw,1)
        raw(kk)=reorderrawdata(kk,1)+i*reorderrawdata(kk,2);
    end
else
    raw=reorderrawdata(:,1)+i*reorderrawdata(:,2);
end


if h.recotype == 2 %spiral3d
    % spiogap neq 0 not yet supported!!!

    if (h.spio==1) | (h.spio ==2)
        if(h.nl > 1) error('h.nl > 1 not yet supported for spio = 1 or 2!!');end;
        h.necho = 2; %in gr, the spiral-out is the first interleaf and the
        %spiral-in is the second.
        raw=reshape(raw,h.nsamp,h.necho,h.nslices,h.ncoil,h.reps);
    elseif (h.spio==3) | (h.spio ==4)
        raw=reshape(raw,h.nsamp,h.nl,h.nslices,h.ncoil,h.reps);
    elseif (h.spio == 0)
        raw=reshape(raw,h.nsamp,h.nl,h.nslices,h.ncoil,h.reps);
    else
        error('spio mode not yet supported!');
    end

else
    raw=reshape(raw,h.nsamp,h.nl,h.ncoil,h.reps,h.necho,h.nslices);
end

% also return some info into h using parseAFNIhead
% if h.necho>1 && h.recotype ~= 2
%     brikN = [Pfilename,'brik_e01+orig'];
% else
%     brikN = [Pfilename,'brik+orig'];
% end

%h = parseAFNIhead(h, brikN, {'voxSize', 'nPix','slGap','spdir1','spdir2'});
%command = ['rm -f ', Pfilename,'_temp*'];
command = 'rm -f pfile_temp*';
system(command);

delete kxkyfiledata.txt reorderrawdata.txt groutput

