function f = kaiser_bessel_zero(dx,width,sigma)

% Returns the 0th order kaiser-bessel function
%
%  -dx is the distance
%  -width is the width of the kernel
%  -sigma determines the shape

% setup
f = zeros(size(dx));
nz = find(abs(dx)<width/2);

% Kaiser-Bessel
temp = realsqrt(1-(2*dx(nz)/width).^2);
f(nz) = bessi0(sigma*temp)/bessi0(sigma);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Replacement for slow matlab besseli function %
% (translated from Numerical Recipes in C)     %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function ans = bessi0(x)

% setup
ax = abs(x);
ans = zeros(size(x));

% ax<3.75
k = find(ax<3.75);
y=x(k)./3.75;
y=y.^2;
ans(k)=1.0+y.*(3.5156229+y.*(3.0899424+y.*(1.2067492 ...
+y.*(0.2659732+y.*(0.360768e-1+y.*0.45813e-2)))));

% ax>=3.75
k = find(ax>=3.75);
y=3.75./ax(k);
ans(k)=(exp(ax(k))./realsqrt(ax(k))).*(0.39894228+y.*(0.1328592e-1 ...
+y.*(0.225319e-2+y.*(-0.157565e-2+y.*(0.916281e-2+y.*(-0.2057706e-1 ...
+y.*(0.2635537e-1+y.*(-0.1647633e-1+y.*0.392377e-2))))))));
