function mat2Brik(Vsize,B,outname,refitBrik,scalef,wCase)
%usage: mat2Brik(Vsize,B,outname,refitBrik,scalef)
% converts matlab data to brik format
%
% Input:
%    Vsize      - Voxel size, e.g [3.75 3.75 8]
%    B          - matlab ND data
%    outname    - output brik name
%    refitBrik  - brik file to refit to, (don't add +orig)
%    scalef     - scale all data by this number, 1000 works well for afni
%    wCase      - how data is written and refit to brik (def = 1)
%
%    e.g.: 
%   mat2Brik([3.75 3.75
%   8],cor.*roi.*sliceRoi,[fmri.dir.data,'/',...
%        fmri.study.name,'/processed/','d3cor'],...
%            [fmri.dir.data,'/',fmri.study.name,...
%            '/processed/',fmri.func(1).name(1,1:end-5),'+reg'],1000)
%
% Copyright (c) 2004 CUPID
% Author: kal
% History:
%  $Id: mat2brik.m,v 1.1 2010/04/21 18:04:40 volafsso Exp $

% ruler
% --1234567890123456789012345678901234567890123456789012345678901234567890

if ~exist('Vsize')  | isempty(Vsize)    Vsize=[];        end
if ~exist('wCase')  | isempty(wCase)    wCase=1;        end

if exist([outname,'+orig.BRIK'])
    tt=sprintf('rm -f %s+orig.BRIK %s+orig.HEAD',...
    outname,outname);eval(['!' tt])
    disp('re-writing old file')
end

%get Vsize
if (isempty(Vsize))
    stat=sprintf('!3dAttribute DELTA %s+orig > temp.txt',refitBrik);
    eval(stat);
    Vsize=load('temp.txt');
    eval('!rm -f temp.txt');
end

%get orient
if exist([refitBrik,'+orig.BRIK'])
    stat=sprintf('!3dAttribute ORIENT_SPECIFIC %s+orig > temp.txt',refitBrik);
    eval(stat);
    onum=load('temp.txt')+1;
    ocode=['R' 'L' 'P' 'A' 'I' 'S'];
    orient=[ocode(onum(1)) ocode(onum(2)) ocode(onum(3))];
    eval('!rm -f temp.txt');
else
    orient='RAI';
end



if ~exist('scalef') scalef=1000; end
sB      = size(B);
if length(sB)==3 sB(4)=1; end
if length(sB)==2 sB(3)=1; sB(4)=1; end
data    = reshape(B.*scalef,prod(sB(1:end-1)),sB(end));

% ran     = double(intmax('int16'));
% neg     = sign(data(:));
% d       = abs(data(:));
% nD      = round(ran.*(d-min(d))./(max(d)-min(d)));
% data    = nD.*neg;
data    = int16(data);
iname   = [outname '.img'];

if ispc
    num=2;
else
    num=1;
end

[a, fInfo]   = unix('more ${FSLDIR}/etc/fslversion');
[a, fotInfo] = unix('env | grep FSLOUTPUTTYPE');

if isempty(str2num(fInfo))
    error('Could not find FSL!')
else
    disp(['FSL version:   ' fInfo]);
end

disp(fotInfo);

if isempty(strfind(fotInfo,'ANALYZE'))
    error('FSLOUTPUTTYPE must be set to ANALYZE!');
end

if str2num(fInfo)>=4
    Isfslnew=1;
elseif str2num(fInfo)>=3
    Isfslnew=0;
else
    warning('Your FSL is old!')
    Isfslnew=0;
end
    

for i=1:num
   
    if Isfslnew
        tt=sprintf('fslcreatehd %g %g %g %g %1.2f %1.2f %g %g %g %g %g %g %s',...
        sB(1), sB(2), sB(3), sB(4), Vsize(1), Vsize(2), Vsize(3), 2, 32, 32, 3, 4, outname);
    else
        tt=sprintf('avwcreatehd %g %g %g %g %1.2f %1.2f %g %g %g %g %g %g %s',...
        sB(1), sB(2), sB(3), sB(4), Vsize(1), Vsize(2), Vsize(3), 2, 32, 32, 3, 4, outname);
    end
    eval(['!' tt])
   
    fid1    = fopen(iname, 'w','n');
    count   = fwrite(fid1,data,'int16');
    fclose(fid1);

end
%avwcreatehd <xsize> <ysize> <zsize> <tsize> <xvoxsize> <yvoxsize> <zvoxsize> <tr> <xorigin> <yorigin> <zorigin> <datatype> <headername>
%<xorigin>,<yorigin>,<zorigin> are arbitrary here. 3drefit can be used to get correct origin if necessary

switch wCase
    case 1 %default case
        tt=sprintf('3dcopy %s.hdr %s',...
            outname,outname);
        eval(['!' tt])

        tt=sprintf('rm -f %s.hdr %s.img',...
            outname,outname);eval(['!' tt])
        if exist([refitBrik,'+orig.BRIK'])
            tt=sprintf('3drefit -orient %s -duporigin %s %s',...
                orient,[refitBrik '+orig'], [outname '+orig']);
            eval(['!' tt])
        end
    case 2 %new case (kal, used to write parahippo)
        inds=strfind(outname,'/');
        outnameN=outname((inds(end)+1):end);
        session=outname(1:inds(end));
        tt=sprintf('to3d -datum byte -session %s -prefix %s -anatparent %s+orig -geomparent %s+orig -orient %s %s.hdr',...
            session,outnameN,refitBrik,refitBrik,orient,outname);
        eval(['!' tt])

        tt=sprintf('rm -f %s.hdr %s.img',...
            outname,outname);eval(['!' tt])
end
