function h = parse_grhead(grhead);
  
% Parse header info from grraw
%  
% USAGE:  h = parse_grhead(grhead);
%
% Inputs:
%    grhead: name of file with header info (e.g. standard output of grraw)
%
% Outputs:
%     h: structure with the following elements
%          nsamp, nl, ncoil, nslices, necho, reps, spdir1, spdir2
%          xoff, yoff
%          if sense is used, also has elements: sense, sptraj
%
%$Id: parse_grhead.m,v 1.2 2010/03/30 00:16:29 volafsso Exp $  
  
fid = fopen(grhead);
doscan = 1;k = 1;

h.recotype = 0; % default is spiral2d
h.spio = 0;
h.spiogap = 0;

while doscan
  ss = fgets(fid);
  if length(ss) > 1
    if strcmp(ss(2:6),'nsamp');
      [a,b,c] = strread(ss,'%s%s%d');
      h.nsamp = c(1);
      h.nl = c(2);
      h.ncoil = c(3);
    end
    if strcmp(ss(2:8),'nslices')
      [a,b,c] = strread(ss,'%s%s%d');
      if length(c) == 4 
          h.nslices = c(1);
          h.necho = c(2);
          h.phases= c(3);
          h.reps= c(4);
      else
          h.nslices = c(1);
          h.necho = c(2);
          h.reps= c(3);
      end
    end
    if strcmp(ss(2:6),'sense')
      [a,b,c] = strread(ss,'%s%s%d');
      h.sense = c(1);
      h.sptraj = c(2);
    end
    if strcmp(ss(2:7),'spdir1')
      [a,b,c] = strread(ss,'%s%s%d');
      h.spdir1 = c(1);
      h.spdir2 = c(2);
    end
    if strcmp(ss(1:4),'xoff')
      [a,b,c] = strread(ss,'%s%s%f');
      h.xoff = c(1);
      h.yoff = c(2);
    end

    if strcmp(ss(2:9),'recotype')
      [a,b,c] = strread(ss,'%s%s%d');
      h.recotype = c(1);
    end

    if strcmp(ss(2:5),'spio')
      [a,b,c] = strread(ss,'%s%s%d');
      h.spio = c(1);
      h.spiogap = c(2);
    end

    if strcmp(ss(2:6),'spres')
      [a,b,c] = strread(ss,'%s%s%d');
      h.spres = c(1);
    end
    
   end  
    k= k+1;if k > 20;doscan = 0;end;
end
fclose(fid);
  
